#ifndef NT2_INCLUDE_CONSTANTS_CNAN_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_CNAN_HPP_INCLUDED

#include <nt2/complex/include/constants/cnan.hpp>

#endif
